@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011, 2014 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 
@@ -11,7 +11,23 @@ use Devel::Trepan::CmdProcessor::Command::Subcmd::Core;
 # Values inherited from parent
 use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
-our $HELP = "Show confirm potentially dangerous operations setting";
+# =pod
+#
+# =head2 Synopsis:
+#
+# =cut
+our $HELP=<<"EOH";
+=pod
+
+B<show confirm>
+Show whether to confirm potentially dangerous operations.
+
+=head2 See also:
+
+L<C<set confirm>|Devel::Trepan::CmdProcessor::Command::Set::Confirm>
+=cut
+EOH
+our $SHORT_HELP = "Show whether to confirm potentially dangerous operations";
 our $MIN_ABBREV = length('co');
 
 if (__FILE__ eq $0) {
